@@ -151,7 +151,9 @@ __all__ = (
     "SourceTypeType",
     "StepExecutionFilterKeyType",
     "StopTypeType",
+    "SSMServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
 )
@@ -501,6 +503,7 @@ StepExecutionFilterKeyType = Literal[
     "StepName",
 ]
 StopTypeType = Literal["Cancel", "Complete"]
+SSMServiceName = Literal["ssm"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -532,6 +535,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -654,6 +658,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -802,6 +807,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "describe_activations",
     "describe_association_execution_targets",
