@@ -6,14 +6,15 @@ Type annotations for ssm service client waiters.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
 
-    from mypy_boto3_ssm import SSMClient
+    from mypy_boto3_ssm.client import SSMClient
     from mypy_boto3_ssm.waiter import (
         CommandExecutedWaiter,
     )
 
-    client: SSMClient = boto3.client("ssm")
+    session = Session()
+    client: SSMClient = session.client("ssm")
 
     command_executed_waiter: CommandExecutedWaiter = client.get_waiter("command_executed")
     ```
@@ -27,7 +28,7 @@ __all__ = ("CommandExecutedWaiter",)
 
 class CommandExecutedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/ssm.html#SSM.Waiter.CommandExecuted)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Waiter.CommandExecuted)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html#commandexecutedwaiter)
     """
 
@@ -40,6 +41,6 @@ class CommandExecutedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/ssm.html#SSM.Waiter.CommandExecuted.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Waiter.CommandExecuted.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html#commandexecutedwaiter)
         """
